Structs
- CEC_CAP
- A bitflag struct for values of the CEC_CAP_* constants
- CEC_
EVENT_ FL - A bitflag struct for values of the CEC_EVENT_FL_* constants
- CEC_
LOG_ ADDRS_ FL - A bitflag struct for values of the CEC_LOG_ADDRS_FL_* constants
- CEC_
LOG_ ADDR_ MASK - A bitflag struct for values of the CEC_LOG_ADDR_MASK_* constants
- CEC_
MSG_ FL - A bitflag struct for values of the CEC_MSG_FL_* constants
- CEC_
RX_ STATUS - A bitflag struct for values of the CEC_RX_STATUS_* constants
- CEC_
TX_ STATUS - A bitflag struct for values of the CEC_TX_STATUS_* constants
- Vendor
Id - Convenience type for the non-zero null vendor ID
- cec_
caps - CEC capabilities structure.
- cec_
connector_ info - Tells if and which connector is associated with the CEC adapter.
- cec_
drm_ connector_ info - Tells which drm connector is associated with the CEC adapter.
- cec_
event - CEC event structure
- cec_
event_ lost_ msgs - Tells you how many messages were lost.
- cec_
event_ state_ change - Used when the CEC adapter changes state.
- cec_
log_ addrs - CEC logical addresses structure
- cec_msg
- CEC message structure.