cec_event_state_change

Struct cec_event_state_change 

#[repr(C)]
pub struct cec_event_state_change { pub phys_addr: PhysicalAddress, pub log_addr_mask: CEC_LOG_ADDR_MASK, pub have_conn_info: u16, }
Used when the CEC adapter changes state.

Fields

phys_addr: PhysicalAddress

The current physical address

log_addr_mask: CEC_LOG_ADDR_MASK

The current logical address mask

have_conn_info: u16

If non-zero, then HDMI connector information is available. This field is only valid if CEC_CAP_CONNECTOR_INFO is set. If that capability is set and have_conn_info is zero, then that indicates that the HDMI connector device is not instantiated, either because the HDMI driver is still configuring the device or because the HDMI device was unbound.